@@ -91,3 +91,16 @@ test_that("wrapper looks good", {
     dbplyr_wrap("db_compute")
   })
 })
+
+test_that("warns if dbplyr is old", {
+  local_mocked_bindings(packageVersion = function(...) "1.0.0")
+  expect_snapshot({
+    check_dbplyr()
+  })
+
+  skip_on_cran()
+  cnd_dplyr <- class(catch_cnd(check_dbplyr()))
+  cnd_startup <- class(catch_cnd(packageStartupMessage("hi")))
+  cnd_startup <- c(cnd_startup[1:2], "rlang_message", cnd_startup[-(1:2)])
+  expect_equal(cnd_dplyr, cnd_startup)
+})
